==> gnome-commander_0.9.6.orig.tar.gz: gnome-commander-0.9.6/src/gnome-cmd-main-win-types.h <==
/*
    GNOME Commander - A GNOME based file manager 
    Copyright (C) 2001-2002 Marcus Bjurman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/ 
#ifndef __GNOME_CMD_MAIN_WIN_TYPES_H__
#define __GNOME_CMD_MAIN_WIN_TYPES_H__


BEGIN_GNOME_DECLS

#define GNOME_CMD_MAIN_WIN(obj) \
	GTK_CHECK_CAST(obj, gnome_cmd_main_win_get_type (), GnomeCmdMainWin)
#define GNOME_CMD_MAIN_WIN_CLASS(klass) \
	GTK_CHECK_CLASS_CAST(klass, gnome_cmd_main_win_get_type (), GnomeCmdMainWinClass)
#define GNOME_IS_CMD_MAIN_WIN(obj) \
	GTK_CHECK_TYPE(obj, gnome_cmd_main_win_get_type ())

typedef struct _GnomeCmdMainWin GnomeCmdMainWin;
typedef struct _GnomeCmdMainWinPrivate GnomeCmdMainWinPrivate;
typedef struct _GnomeCmdMainWinClass GnomeCmdMainWinClass;


struct _GnomeCmdMainWin
{
	GnomeApp parent;
	GnomeCmdMainWinPrivate *priv;
};

struct _GnomeCmdMainWinClass
{
	GnomeAppClass parent_class;
};

#endif //__GNOME_CMD_MAIN_WIN_TYPES_H__

==> gnome-commander_1.0.1.orig.tar.gz: gnome-commander-1.0.1/src/gnome-cmd-main-win-types.h <==
/*
    GNOME Commander - A GNOME based file manager 
    Copyright (C) 2001-2003 Marcus Bjurman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/ 
#ifndef __GNOME_CMD_MAIN_WIN_TYPES_H__
#define __GNOME_CMD_MAIN_WIN_TYPES_H__

#include "gnome-cmd-file-selector-types.h"

BEGIN_GNOME_DECLS

#define GNOME_CMD_MAIN_WIN(obj) \
	GTK_CHECK_CAST(obj, gnome_cmd_main_win_get_type (), GnomeCmdMainWin)
#define GNOME_CMD_MAIN_WIN_CLASS(klass) \
	GTK_CHECK_CLASS_CAST(klass, gnome_cmd_main_win_get_type (), GnomeCmdMainWinClass)
#define GNOME_CMD_IS_MAIN_WIN(obj) \
	GTK_CHECK_TYPE(obj, gnome_cmd_main_win_get_type ())

typedef struct _GnomeCmdMainWin GnomeCmdMainWin;
typedef struct _GnomeCmdMainWinPrivate GnomeCmdMainWinPrivate;
typedef struct _GnomeCmdMainWinClass GnomeCmdMainWinClass;


struct _GnomeCmdMainWin
{
	GnomeApp parent;
	GnomeCmdMainWinPrivate *priv;
};

struct _GnomeCmdMainWinClass
{
	GnomeAppClass parent_class;

	void (* switch_fs)       (GnomeCmdMainWin *mw,
							  GnomeCmdFileSelector *fs);
};


extern GnomeCmdMainWin *main_win;


#endif //__GNOME_CMD_MAIN_WIN_TYPES_H__
